.. :changelog:

History
-------

0.5.0.3 (2013-09-15)
++++++++++++++++++++

- Important API change Bootstrap to JqueryUiBootstrap (Flask-Bootstrap no conflict)

0.5.0.1 (2013-08-26)
++++++++++++++++++++

- Initial version
